# Copyright (c) 2021 AccelByte Inc. All Rights Reserved.
# This is licensed software from AccelByte Inc, for limitations
# and restrictions contact your company contract manager.
#
# Code generated. DO NOT EDIT!

# template file: ags_py_codegen

"""Auto-generated package that contains models used by the AccelByte Gaming Services Challenge Service."""

__version__ = "1.11.1"
__author__ = "AccelByte"
__email__ = "dev@accelbyte.net"

# pylint: disable=line-too-long

from .admin_create_assignment_plugin import AdminCreateAssignmentPlugin
from .admin_delete_assignment_plugin import AdminDeleteAssignmentPlugin
from .admin_get_assignment_plugin import AdminGetAssignmentPlugin
from .admin_update_assignment_plugin import AdminUpdateAssignmentPlugin
