# Copyright (c) 2021 AccelByte Inc. All Rights Reserved.
# This is licensed software from AccelByte Inc, for limitations
# and restrictions contact your company contract manager.
#
# Code generated. DO NOT EDIT!

# template file: ags_py_codegen

"""Auto-generated package that contains models used by the AccelByte Gaming Services Basic Service."""

__version__ = "4.0.0"
__author__ = "AccelByte"
__email__ = "dev@accelbyte.net"

# pylint: disable=line-too-long

from .change_namespace_status import ChangeNamespaceStatus
from .create_namespace import CreateNamespace
from .delete_namespace import DeleteNamespace
from .get_child_namespaces import GetChildNamespaces
from .get_game_namespaces import GetGameNamespaces
from .get_namespace import GetNamespace
from .get_namespace_1 import GetNamespace1
from .get_namespace_context import GetNamespaceContext
from .get_namespace_publisher import GetNamespacePublisher
from .get_namespaces import GetNamespaces
from .public_get_namespace_publisher import PublicGetNamespacePublisher
from .public_get_namespaces import PublicGetNamespaces
from .update_namespace import UpdateNamespace
