# Copyright (c) 2021 AccelByte Inc. All Rights Reserved.
# This is licensed software from AccelByte Inc, for limitations
# and restrictions contact your company contract manager.
#
# Code generated. DO NOT EDIT!

# template file: ags_py_codegen

"""Auto-generated package that contains models used by the AccelByte Gaming Services Chat Service."""

__version__ = "0.4.36"
__author__ = "AccelByte"
__email__ = "dev@accelbyte.net"

# pylint: disable=line-too-long

from .admin_add_inbox_category import AdminAddInboxCategory
from .admin_delete_inbox_category import AdminDeleteInboxCategory
from .admin_delete_inbox_message import AdminDeleteInboxMessage
from .admin_get_category_schema import AdminGetCategorySchema
from .admin_get_inbox_categories import AdminGetInboxCategories
from .admin_get_inbox_messages import AdminGetInboxMessages
from .admin_get_inbox_messages import (
    ScopeEnum as AdminGetInboxMessagesScopeEnum,
    StatusEnum as AdminGetInboxMessagesStatusEnum,
)
from .admin_get_inbox_stats import AdminGetInboxStats
from .admin_get_inbox_users import AdminGetInboxUsers
from .admin_get_inbox_users import StatusEnum as AdminGetInboxUsersStatusEnum
from .admin_save_inbox_message import AdminSaveInboxMessage
from .admin_send_inbox_message import AdminSendInboxMessage
from .admin_unsend_inbox_message import AdminUnsendInboxMessage
from .admin_update_inbox_category import AdminUpdateInboxCategory
from .admin_update_inbox_message import AdminUpdateInboxMessage
