# Copyright (c) 2021 AccelByte Inc. All Rights Reserved.
# This is licensed software from AccelByte Inc, for limitations
# and restrictions contact your company contract manager.
#
# Code generated. DO NOT EDIT!

# template file: ags_py_codegen

"""Auto-generated package that contains models used by the AccelByte Gaming Services Inventory Service."""

__version__ = "0.2.7"
__author__ = "AccelByte"
__email__ = "dev@accelbyte.net"

# pylint: disable=line-too-long

from .admin_create_inventory import AdminCreateInventory
from .admin_get_inventory import AdminGetInventory
from .admin_list_inventories import AdminListInventories
from .admin_list_inventories import SortByEnum as AdminListInventoriesSortByEnum
from .admin_purchasable import AdminPurchasable
from .admin_update_inventory import AdminUpdateInventory
from .admin_update_user_inven_6f94a4 import AdminUpdateUserInventoriesByInventoryCode
from .delete_inventory import DeleteInventory
