# Copyright (c) 2021 AccelByte Inc. All Rights Reserved.
# This is licensed software from AccelByte Inc, for limitations
# and restrictions contact your company contract manager.
#
# Code generated. DO NOT EDIT!

# template file: ags_py_codegen

# AccelByte Gaming Services Inventory Service

# pylint: disable=duplicate-code
# pylint: disable=line-too-long
# pylint: disable=missing-function-docstring
# pylint: disable=missing-module-docstring
# pylint: disable=too-many-arguments
# pylint: disable=too-many-branches
# pylint: disable=too-many-instance-attributes
# pylint: disable=too-many-lines
# pylint: disable=too-many-locals
# pylint: disable=too-many-public-methods
# pylint: disable=too-many-return-statements
# pylint: disable=too-many-statements
# pylint: disable=unused-import

from __future__ import annotations
from typing import Any, Dict, List, Optional, Tuple, Union

from ....core import Model

from ..models.apimodels_bulk_save_item_error import ApimodelsBulkSaveItemError
from ..models.apimodels_item_resp import ApimodelsItemResp


class ApimodelsBulkSaveItemResp(Model):
    """Apimodels bulk save item resp (apimodels.BulkSaveItemResp)

    Properties:
        success: (success) REQUIRED bool

        error_details: (errorDetails) OPTIONAL ApimodelsBulkSaveItemError

        item: (item) OPTIONAL ApimodelsItemResp
    """

    # region fields

    success: bool  # REQUIRED
    error_details: ApimodelsBulkSaveItemError  # OPTIONAL
    item: ApimodelsItemResp  # OPTIONAL

    # endregion fields

    # region with_x methods

    def with_success(self, value: bool) -> ApimodelsBulkSaveItemResp:
        self.success = value
        return self

    def with_error_details(
        self, value: ApimodelsBulkSaveItemError
    ) -> ApimodelsBulkSaveItemResp:
        self.error_details = value
        return self

    def with_item(self, value: ApimodelsItemResp) -> ApimodelsBulkSaveItemResp:
        self.item = value
        return self

    # endregion with_x methods

    # region to methods

    def to_dict(self, include_empty: bool = False) -> dict:
        result: dict = {}
        if hasattr(self, "success"):
            result["success"] = bool(self.success)
        elif include_empty:
            result["success"] = False
        if hasattr(self, "error_details"):
            result["errorDetails"] = self.error_details.to_dict(
                include_empty=include_empty
            )
        elif include_empty:
            result["errorDetails"] = ApimodelsBulkSaveItemError()
        if hasattr(self, "item"):
            result["item"] = self.item.to_dict(include_empty=include_empty)
        elif include_empty:
            result["item"] = ApimodelsItemResp()
        return result

    # endregion to methods

    # region static methods

    @classmethod
    def create(
        cls,
        success: bool,
        error_details: Optional[ApimodelsBulkSaveItemError] = None,
        item: Optional[ApimodelsItemResp] = None,
        **kwargs,
    ) -> ApimodelsBulkSaveItemResp:
        instance = cls()
        instance.success = success
        if error_details is not None:
            instance.error_details = error_details
        if item is not None:
            instance.item = item
        return instance

    @classmethod
    def create_from_dict(
        cls, dict_: dict, include_empty: bool = False
    ) -> ApimodelsBulkSaveItemResp:
        instance = cls()
        if not dict_:
            return instance
        if "success" in dict_ and dict_["success"] is not None:
            instance.success = bool(dict_["success"])
        elif include_empty:
            instance.success = False
        if "errorDetails" in dict_ and dict_["errorDetails"] is not None:
            instance.error_details = ApimodelsBulkSaveItemError.create_from_dict(
                dict_["errorDetails"], include_empty=include_empty
            )
        elif include_empty:
            instance.error_details = ApimodelsBulkSaveItemError()
        if "item" in dict_ and dict_["item"] is not None:
            instance.item = ApimodelsItemResp.create_from_dict(
                dict_["item"], include_empty=include_empty
            )
        elif include_empty:
            instance.item = ApimodelsItemResp()
        return instance

    @classmethod
    def create_many_from_dict(
        cls, dict_: dict, include_empty: bool = False
    ) -> Dict[str, ApimodelsBulkSaveItemResp]:
        return (
            {k: cls.create_from_dict(v, include_empty=include_empty) for k, v in dict_}
            if dict_
            else {}
        )

    @classmethod
    def create_many_from_list(
        cls, list_: list, include_empty: bool = False
    ) -> List[ApimodelsBulkSaveItemResp]:
        return (
            [cls.create_from_dict(i, include_empty=include_empty) for i in list_]
            if list_
            else []
        )

    @classmethod
    def create_from_any(
        cls, any_: any, include_empty: bool = False, many: bool = False
    ) -> Union[
        ApimodelsBulkSaveItemResp,
        List[ApimodelsBulkSaveItemResp],
        Dict[Any, ApimodelsBulkSaveItemResp],
    ]:
        if many:
            if isinstance(any_, dict):
                return cls.create_many_from_dict(any_, include_empty=include_empty)
            elif isinstance(any_, list):
                return cls.create_many_from_list(any_, include_empty=include_empty)
            else:
                raise ValueError()
        else:
            return cls.create_from_dict(any_, include_empty=include_empty)

    @staticmethod
    def get_field_info() -> Dict[str, str]:
        return {
            "success": "success",
            "errorDetails": "error_details",
            "item": "item",
        }

    @staticmethod
    def get_required_map() -> Dict[str, bool]:
        return {
            "success": True,
            "errorDetails": False,
            "item": False,
        }

    # endregion static methods
