# Copyright (c) 2021 AccelByte Inc. All Rights Reserved.
# This is licensed software from AccelByte Inc, for limitations
# and restrictions contact your company contract manager.
#
# Code generated. DO NOT EDIT!

# template file: ags_py_codegen

"""Auto-generated package that contains models used by the AccelByte Gaming Services Gdpr Service."""

__version__ = "2.15.0"
__author__ = "AccelByte"
__email__ = "dev@accelbyte.net"

# pylint: disable=line-too-long

from .admin_get_platform_acco_c23147 import (
    AdminGetPlatformAccountClosureServicesConfiguration,
)
from .admin_get_services_conf_be46ef import AdminGetServicesConfiguration
from .admin_reset_platform_ac_c4b31b import (
    AdminResetPlatformAccountClosureServicesConfiguration,
)
from .admin_reset_services_co_abf06c import AdminResetServicesConfiguration
from .admin_update_platform_a_1f24aa import (
    AdminUpdatePlatformAccountClosureServicesConfiguration,
)
from .admin_update_services_c_ea010e import AdminUpdateServicesConfiguration
from .delete_admin_email_conf_009cca import DeleteAdminEmailConfiguration
from .get_admin_email_configuration import GetAdminEmailConfiguration
from .save_admin_email_configuration import SaveAdminEmailConfiguration
from .update_admin_email_conf_71e966 import UpdateAdminEmailConfiguration
