# Copyright (c) 2021 AccelByte Inc. All Rights Reserved.
# This is licensed software from AccelByte Inc, for limitations
# and restrictions contact your company contract manager.
#
# Code generated. DO NOT EDIT!

# template file: ags_py_codegen

"""Auto-generated package that contains models used by the AccelByte Gaming Services Legal Service."""

__version__ = "4.0.0"
__author__ = "AccelByte"
__email__ = "dev@accelbyte.net"

# pylint: disable=line-too-long

from .create_policy_version import CreatePolicyVersion
from .publish_policy_version import PublishPolicyVersion
from .retrieve_single_policy_version import RetrieveSinglePolicyVersion
from .update_policy_version import UpdatePolicyVersion
