# Copyright (c) 2021 AccelByte Inc. All Rights Reserved.
# This is licensed software from AccelByte Inc, for limitations
# and restrictions contact your company contract manager.
#
# Code generated. DO NOT EDIT!

# template file: ags_py_codegen

"""Auto-generated package that contains models used by the AccelByte Gaming Services Platform Service."""

__version__ = "6.0.0"
__author__ = "AccelByte"
__email__ = "dev@accelbyte.net"

# pylint: disable=line-too-long

from .get_subscription_history import GetSubscriptionHistory
from .get_third_party_platfor_a863f8 import (
    GetThirdPartyPlatformSubscriptionOwnershipByGroupId,
)
from .get_third_party_platfor_a863f8 import (
    PlatformEnum as GetThirdPartyPlatformSubscriptionOwnershipByGroupIdPlatformEnum,
)
from .get_third_party_platfor_62d92f import (
    GetThirdPartyPlatformSubscriptionOwnershipByProductId,
)
from .get_third_party_platfor_62d92f import (
    PlatformEnum as GetThirdPartyPlatformSubscriptionOwnershipByProductIdPlatformEnum,
)
from .get_third_party_subscri_c77bab import GetThirdPartySubscriptionDetails
from .get_third_party_user_su_0efa78 import GetThirdPartyUserSubscriptionDetails
from .public_query_user_third_9368be import PublicQueryUserThirdPartySubscription
from .public_query_user_third_9368be import (
    PlatformEnum as PublicQueryUserThirdPartySubscriptionPlatformEnum,
)
from .query_third_party_subscription import QueryThirdPartySubscription
from .query_third_party_subscription import (
    PlatformEnum as QueryThirdPartySubscriptionPlatformEnum,
)
from .query_user_third_party__364a48 import QueryUserThirdPartySubscription
from .query_user_third_party__364a48 import (
    PlatformEnum as QueryUserThirdPartySubscriptionPlatformEnum,
)
from .query_user_third_party__c82a8c import QueryUserThirdPartySubscriptionTransactions
from .query_user_third_party__c82a8c import (
    PlatformEnum as QueryUserThirdPartySubscriptionTransactionsPlatformEnum,
)
from .sync_subscription import SyncSubscription
from .sync_subscription_transaction import SyncSubscriptionTransaction
