# Copyright (c) 2021 AccelByte Inc. All Rights Reserved.
# This is licensed software from AccelByte Inc, for limitations
# and restrictions contact your company contract manager.
#
# Code generated. DO NOT EDIT!

# template file: ags_py_codegen

"""Auto-generated package that contains models used by the AccelByte Gaming Services Reporting Service."""

__version__ = "0.1.38"
__author__ = "AccelByte"
__email__ = "dev@accelbyte.net"

# pylint: disable=line-too-long

from ._admin_configurations import get
from ._admin_configurations import get_async
from ._admin_configurations import upsert
from ._admin_configurations import upsert_async

from ._admin_extension_categories_and_auto_moderation_actions import (
    admin_create_extension_category,
)
from ._admin_extension_categories_and_auto_moderation_actions import (
    admin_create_extension_category_async,
)
from ._admin_extension_categories_and_auto_moderation_actions import (
    admin_create_mod_action,
)
from ._admin_extension_categories_and_auto_moderation_actions import (
    admin_create_mod_action_async,
)
from ._admin_extension_categories_and_auto_moderation_actions import (
    admin_find_action_list,
)
from ._admin_extension_categories_and_auto_moderation_actions import (
    admin_find_action_list_async,
)
from ._admin_extension_categories_and_auto_moderation_actions import (
    admin_find_extension_category_list,
)
from ._admin_extension_categories_and_auto_moderation_actions import (
    admin_find_extension_category_list_async,
)

from ._admin_moderation_rule import create_moderation_rule
from ._admin_moderation_rule import create_moderation_rule_async
from ._admin_moderation_rule import delete_moderation_rule
from ._admin_moderation_rule import delete_moderation_rule_async
from ._admin_moderation_rule import get_moderation_rule_details
from ._admin_moderation_rule import get_moderation_rule_details_async
from ._admin_moderation_rule import get_moderation_rules
from ._admin_moderation_rule import get_moderation_rules_async
from ._admin_moderation_rule import update_moderation_rule
from ._admin_moderation_rule import update_moderation_rule_async
from ._admin_moderation_rule import update_moderation_rule_status
from ._admin_moderation_rule import update_moderation_rule_status_async

from ._admin_reasons import admin_get_all_reasons
from ._admin_reasons import admin_get_all_reasons_async
from ._admin_reasons import admin_get_reason
from ._admin_reasons import admin_get_reason_async
from ._admin_reasons import admin_get_reasons
from ._admin_reasons import admin_get_reasons_async
from ._admin_reasons import admin_get_unused_reasons
from ._admin_reasons import admin_get_unused_reasons_async
from ._admin_reasons import admin_list_reason_groups
from ._admin_reasons import admin_list_reason_groups_async
from ._admin_reasons import create_reason
from ._admin_reasons import create_reason_async
from ._admin_reasons import create_reason_group
from ._admin_reasons import create_reason_group_async
from ._admin_reasons import delete_reason
from ._admin_reasons import delete_reason_async
from ._admin_reasons import delete_reason_group
from ._admin_reasons import delete_reason_group_async
from ._admin_reasons import get_reason_group
from ._admin_reasons import get_reason_group_async
from ._admin_reasons import update_reason
from ._admin_reasons import update_reason_async
from ._admin_reasons import update_reason_group
from ._admin_reasons import update_reason_group_async

from ._admin_reports import admin_submit_report
from ._admin_reports import admin_submit_report_async
from ._admin_reports import list_reports
from ._admin_reports import list_reports_async

from ._admin_tickets import delete_ticket
from ._admin_tickets import delete_ticket_async
from ._admin_tickets import get_reports_by_ticket
from ._admin_tickets import get_reports_by_ticket_async
from ._admin_tickets import get_ticket_detail
from ._admin_tickets import get_ticket_detail_async
from ._admin_tickets import list_tickets
from ._admin_tickets import list_tickets_async
from ._admin_tickets import ticket_statistic
from ._admin_tickets import ticket_statistic_async
from ._admin_tickets import update_ticket_resolutions
from ._admin_tickets import update_ticket_resolutions_async

from ._public_reasons import public_get_reasons
from ._public_reasons import public_get_reasons_async
from ._public_reasons import public_list_reason_groups
from ._public_reasons import public_list_reason_groups_async

from ._public_reports import submit_report
from ._public_reports import submit_report_async
