# Copyright (c) 2021 AccelByte Inc. All Rights Reserved.
# This is licensed software from AccelByte Inc, for limitations
# and restrictions contact your company contract manager.
#
# Code generated. DO NOT EDIT!

# template file: ags_py_codegen

"""Auto-generated package that contains models used by the AccelByte Gaming Services Legal Service."""

__version__ = "4.0.0"
__author__ = "AccelByte"
__email__ = "dev@accelbyte.net"

# pylint: disable=line-too-long

from .accept_versioned_policy import AcceptVersionedPolicy
from .bulk_accept_versioned_policy import BulkAcceptVersionedPolicy
from .change_preference_consent import ChangePreferenceConsent
from .change_preference_consent_1 import ChangePreferenceConsent1
from .indirect_bulk_accept_ve_f4345a import IndirectBulkAcceptVersionedPolicy1
from .indirect_bulk_accept_ve_34e753 import IndirectBulkAcceptVersionedPolicyV2
from .retrieve_accepted_agreements import RetrieveAcceptedAgreements
from .retrieve_agreements_public import RetrieveAgreementsPublic
from .retrieve_all_users_by_p_90a012 import RetrieveAllUsersByPolicyVersion
