# Copyright (c) 2021 AccelByte Inc. All Rights Reserved.
# This is licensed software from AccelByte Inc, for limitations
# and restrictions contact your company contract manager.
#
# Code generated. DO NOT EDIT!

# template file: ags_py_codegen

"""Auto-generated package that contains models used by the AccelByte Gaming Services Session Service."""

__version__ = "3.20.0"
__author__ = "AccelByte"
__email__ = "dev@accelbyte.net"

# pylint: disable=line-too-long

from ._certificate import admin_upload_x_box_certificate
from ._certificate import admin_upload_x_box_certificate_async

from ._config import admin_get_log_config
from ._config import admin_get_log_config_async
from ._config import admin_patch_update_log_config
from ._config import admin_patch_update_log_config_async

from ._configuration_template import admin_create_configuration_alert_v1
from ._configuration_template import admin_create_configuration_alert_v1_async
from ._configuration_template import admin_create_configuration_template_v1
from ._configuration_template import admin_create_configuration_template_v1_async
from ._configuration_template import admin_delete_configuration_alert_v1
from ._configuration_template import admin_delete_configuration_alert_v1_async
from ._configuration_template import admin_delete_configuration_template_v1
from ._configuration_template import admin_delete_configuration_template_v1_async
from ._configuration_template import admin_get_all_configuration_templates_v1
from ._configuration_template import admin_get_all_configuration_templates_v1_async
from ._configuration_template import admin_get_configuration_alert_v1
from ._configuration_template import admin_get_configuration_alert_v1_async
from ._configuration_template import admin_get_configuration_template_v1
from ._configuration_template import admin_get_configuration_template_v1_async
from ._configuration_template import admin_get_dsmc_configuration
from ._configuration_template import admin_get_dsmc_configuration_async
from ._configuration_template import admin_sync_dsmc_configuration
from ._configuration_template import admin_sync_dsmc_configuration_async
from ._configuration_template import admin_update_configuration_alert_v1
from ._configuration_template import admin_update_configuration_alert_v1_async
from ._configuration_template import admin_update_configuration_template_v1
from ._configuration_template import admin_update_configuration_template_v1_async

from ._dsmc_default_configuration import admin_get_dsmc_configuration_default
from ._dsmc_default_configuration import admin_get_dsmc_configuration_default_async

from ._environment_variable import admin_list_environment_variables
from ._environment_variable import admin_list_environment_variables_async

from ._game_session import admin_delete_bulk_game_sessions
from ._game_session import admin_delete_bulk_game_sessions_async
from ._game_session import admin_kick_game_session_member
from ._game_session import admin_kick_game_session_member_async
from ._game_session import admin_query_game_sessions
from ._game_session import admin_query_game_sessions_async
from ._game_session import admin_query_game_sessions_by_attributes
from ._game_session import admin_query_game_sessions_by_attributes_async
from ._game_session import admin_set_ds_ready
from ._game_session import admin_set_ds_ready_async
from ._game_session import admin_update_game_session_member
from ._game_session import admin_update_game_session_member_async
from ._game_session import append_team_game_session
from ._game_session import append_team_game_session_async
from ._game_session import create_game_session
from ._game_session import create_game_session_async
from ._game_session import delete_game_session
from ._game_session import delete_game_session_async
from ._game_session import game_session_generate_code
from ._game_session import game_session_generate_code_async
from ._game_session import get_game_session
from ._game_session import get_game_session_async
from ._game_session import get_game_session_by_pod_name
from ._game_session import get_game_session_by_pod_name_async
from ._game_session import get_session_server_secret
from ._game_session import get_session_server_secret_async
from ._game_session import join_game_session
from ._game_session import join_game_session_async
from ._game_session import leave_game_session
from ._game_session import leave_game_session_async
from ._game_session import patch_update_game_session
from ._game_session import patch_update_game_session_async
from ._game_session import public_game_session_cancel
from ._game_session import public_game_session_cancel_async
from ._game_session import public_game_session_invite
from ._game_session import public_game_session_invite_async
from ._game_session import public_game_session_reject
from ._game_session import public_game_session_reject_async
from ._game_session import public_kick_game_session_member
from ._game_session import public_kick_game_session_member_async
from ._game_session import public_promote_game_session_leader
from ._game_session import public_promote_game_session_leader_async
from ._game_session import public_query_game_sessions_by_attributes
from ._game_session import public_query_game_sessions_by_attributes_async
from ._game_session import public_query_my_game_sessions
from ._game_session import public_query_my_game_sessions_async
from ._game_session import public_revoke_game_session_code
from ._game_session import public_revoke_game_session_code_async
from ._game_session import public_session_join_code
from ._game_session import public_session_join_code_async
from ._game_session import update_game_session
from ._game_session import update_game_session_async
from ._game_session import update_game_session_backfill_ticket_id
from ._game_session import update_game_session_backfill_ticket_id_async

from ._global_configuration import admin_delete_global_configuration
from ._global_configuration import admin_delete_global_configuration_async
from ._global_configuration import admin_list_global_configuration
from ._global_configuration import admin_list_global_configuration_async
from ._global_configuration import admin_update_global_configuration
from ._global_configuration import admin_update_global_configuration_async

from ._max_active import admin_get_member_active_session
from ._max_active import admin_get_member_active_session_async
from ._max_active import admin_reconcile_max_active_session
from ._max_active import admin_reconcile_max_active_session_async

from ._native_session import admin_get_list_native_session
from ._native_session import admin_get_list_native_session_async

from ._operations import get_healthcheck_info
from ._operations import get_healthcheck_info_async
from ._operations import get_healthcheck_info_v1
from ._operations import get_healthcheck_info_v1_async

from ._party import admin_delete_bulk_parties
from ._party import admin_delete_bulk_parties_async
from ._party import admin_query_parties
from ._party import admin_query_parties_async
from ._party import admin_sync_native_session
from ._party import admin_sync_native_session_async
from ._party import public_create_party
from ._party import public_create_party_async
from ._party import public_generate_party_code
from ._party import public_generate_party_code_async
from ._party import public_get_party
from ._party import public_get_party_async
from ._party import public_party_cancel
from ._party import public_party_cancel_async
from ._party import public_party_invite
from ._party import public_party_invite_async
from ._party import public_party_join
from ._party import public_party_join_async
from ._party import public_party_join_code
from ._party import public_party_join_code_async
from ._party import public_party_kick
from ._party import public_party_kick_async
from ._party import public_party_leave
from ._party import public_party_leave_async
from ._party import public_party_reject
from ._party import public_party_reject_async
from ._party import public_patch_update_party
from ._party import public_patch_update_party_async
from ._party import public_promote_party_leader
from ._party import public_promote_party_leader_async
from ._party import public_query_my_parties
from ._party import public_query_my_parties_async
from ._party import public_revoke_party_code
from ._party import public_revoke_party_code_async
from ._party import public_update_party
from ._party import public_update_party_async

from ._platform_credential import admin_delete_platform_credentials
from ._platform_credential import admin_delete_platform_credentials_async
from ._platform_credential import admin_delete_platform_credentials_by_platform_id
from ._platform_credential import admin_delete_platform_credentials_by_platform_id_async
from ._platform_credential import admin_get_platform_credentials
from ._platform_credential import admin_get_platform_credentials_async
from ._platform_credential import admin_sync_platform_credentials
from ._platform_credential import admin_sync_platform_credentials_async
from ._platform_credential import admin_update_platform_credentials
from ._platform_credential import admin_update_platform_credentials_async

from ._player import admin_get_player_attributes
from ._player import admin_get_player_attributes_async
from ._player import admin_query_player_attributes
from ._player import admin_query_player_attributes_async
from ._player import public_delete_player_attributes
from ._player import public_delete_player_attributes_async
from ._player import public_get_bulk_player_current_platform
from ._player import public_get_bulk_player_current_platform_async
from ._player import public_get_player_attributes
from ._player import public_get_player_attributes_async
from ._player import public_store_player_attributes
from ._player import public_store_player_attributes_async

from ._recent_player import admin_get_recent_player
from ._recent_player import admin_get_recent_player_async
from ._recent_player import admin_get_recent_team_player
from ._recent_player import admin_get_recent_team_player_async
from ._recent_player import public_get_recent_player
from ._recent_player import public_get_recent_player_async
from ._recent_player import public_get_recent_team_player
from ._recent_player import public_get_recent_team_player_async

from ._session_storage import admin_delete_user_session_storage
from ._session_storage import admin_delete_user_session_storage_async
from ._session_storage import admin_read_session_storage
from ._session_storage import admin_read_session_storage_async
from ._session_storage import admin_read_user_session_storage
from ._session_storage import admin_read_user_session_storage_async
from ._session_storage import public_update_insert_session_storage
from ._session_storage import public_update_insert_session_storage_async
from ._session_storage import public_update_insert_session_storage_leader
from ._session_storage import public_update_insert_session_storage_leader_async
